@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/* gtksourcecompletion.c
+/*
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2007 -2009 Jesús Barbero Rodríguez <chuchiperriman@gmail.com>
@@ -102,6 +102,7 @@
 
 #include "gtksourcecompletion.h"
 #include "gtksourcecompletion-private.h"
+#include <glib/gi18n-lib.h>
 #include "gtksourcecompletionmodel.h"
 #include "gtksourcecompletioncontext.h"
 #include "gtksourcecompletioninfo.h"
@@ -110,7 +111,6 @@
 #include "gtksourcecompletioncontainer.h"
 #include "gtksourcebuffer.h"
 #include "gtksourceview.h"
-#include "gtksourceview-i18n.h"
 
 enum
 {
