@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*- */
-/* gtksourceencoding.c
+/*
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2002-2005 - Paolo Maggi
@@ -25,7 +25,7 @@
 
 #include "gtksourceencoding.h"
 #include "gtksourceencoding-private.h"
-#include "gtksourceview-i18n.h"
+#include <glib/gi18n-lib.h>
 
 /**
  * SECTION:encoding
