@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- * gtksourcegutterrenderer.c
+ *
  * This file is part of GtkSourceView
  *
  * Copyright (C) 2010 - Jesse van den Kieboom
@@ -25,8 +25,7 @@
 #include "gtksourcegutterrenderer.h"
 #include "gtksourcegutterrenderer-private.h"
 #include "gtksourcestylescheme.h"
-#include "gtksourceview-enumtypes.h"
-#include "gtksourceview-i18n.h"
+#include "gtksource-enumtypes.h"
 
 /**
  * SECTION:gutterrenderer
