@@ -1,5 +1,5 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8; coding: utf-8 -*-
- * gtksourcelanguage-parser-2.c
+ *
  * Language specification parser for 2.0 version .lang files
  * This file is part of GtkSourceView
  *
@@ -32,7 +32,6 @@
 #include <config.h>
 #endif
 
-#include "gtksourceview-i18n.h"
 #include "gtksourcebuffer.h"
 #include "gtksourcelanguage.h"
 #include "gtksourcelanguage-private.h"
@@ -40,6 +39,7 @@
 
 #include <glib.h>
 #include <glib/gstdio.h>
+#include <glib/gi18n-lib.h>
 
 #include <string.h>
 #include <fcntl.h>
